indicatortools.IndicatorExpression
==================================

.. abjad-lineage:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression

.. autoclass:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.component
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.indicator
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.scope
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__copy__
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__eq__
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__format__
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__hash__
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__ne__
      ~abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.component
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.indicator
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.scope
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.IndicatorExpression.IndicatorExpression.__repr__
   :noindex:
